pub fn run<I>(args: I) -> Result<()>where
I: IntoIterator<Item = String>,Expand description
Run the CLI over args (the program’s arguments, excluding argv[0]).
Errors
Returns an error if the input file cannot be read, standard input cannot be read, or an unknown flag is supplied.